the soundtools library has some basic sound-waves which you can use to create music, and you can modify it and add you own sound-waves as well.

```shell
pip install -U soundtools
```

```python
import soundtools
```